#!/usr/bin/env python3
"""
from teamconnector.restricted import *
split_gz_file(tar_gz(folder_path, outdir='~/Downloads/'), n_chunks=10)

from teamconnector.restricted import *
untar_gz(merge_tar_files(split_file_pattern), '~/Downloads/')

sync_downloads(source_path, destination_path, debug=False)
"""

import os
import subprocess

def tar_gz(folder_path, archive_path=None, outdir=None):
    """Create a compressed archive of a folder using tar and gzip."""
    if archive_path is None:
        folder_name = os.path.basename(folder_path)
        archive_path = f"{folder_name}.tar.gz"
    if outdir is not None:
        archive_path = os.path.join(outdir, archive_path)
    cmd = ["tar", "-czvf", archive_path, folder_path]
    subprocess.run(cmd, check=True)
    return archive_path

def split_gz_file(tar_file_path, n_chunks):
    """Split a tarred file into n chunks using the split command."""
    subprocess.run(["split", "-n", str(n_chunks), "-d", tar_file_path, f"{tar_file_path}.part-"], check=True)
    return tar_file_path
    
def merge_tar_files(split_file_pattern, tar_file_path=None):
    """Merge split tar files back into a single tar file."""
    if tar_file_path is None:
        tar_file_path = os.path.splitext(split_file_pattern)[0]
    subprocess.run(["cat", f"{split_file_pattern}*",
                    ">", tar_file_path], check=True)
    return tar_file_path
    
def untar_gz(archive_path, extract_path="."):
    """Extract the contents of a compressed archive using tar."""
    cmd = ["tar", "-xzvf", archive_path, "-C", extract_path]
    subprocess.run(cmd, check=True)

def sync_download(source_path, destination_path, debug=False):
    """Copy the contents of a folder to another folder using rsync."""
    cmd = ["rsync", "-avhW"]
    if debug:
        cmd.append("--dry-run")
    cmd.extend([source_path, destination_path])
    subprocess.run(cmd, check=True)



import re
import os
import subprocess


def sync_bucket(args):
    """Sync a local directory to a Google Cloud Storage bucket using gsutil."""
    try:
        drive_dir = f"{os.environ['CLOUD_ROOT']}"
        drive_dir = re.sub('^gs://', '', drive_dir)
    except KeyError:
        print('CLOUD_ROOT environment variable is not defined. Error...')
        exit()
    local_dir = f"{args.folder}/{args.subdir}/"
    drive_dir = f"{drive_dir}/{args.folder}/{args.subdir}/"
    if args.open:
        subprocess.call(
            ['open', 'https://console.cloud.google.com/storage/browser/' + drive_dir])
        return
    if args.list:
        cmd = ["gsutil", "ls", f"gs://{drive_dir}"]
        subprocess.run(cmd, check=True)
        return
    cmd = ["gsutil", "-m", "rsync", "-x",
           ".*\.ht|.*\.mt|.*\.vcf|.*\.log", "-r"]
    if args.debug:
        cmd.append("-n")
    if args.dir == 'up':
        cmd.extend([local_dir, f"gs://{drive_dir}"])
    else:
        cmd.extend([f"gs://{drive_dir}", local_dir])
    print(" ".join(cmd))
    subprocess.run(cmd, check=True)



import os
import pkg_resources

# define PROJECT_ROOT environment variable
try:
    PROJECT_ROOT = os.path.abspath(
        pkg_resources.resource_filename(pkg_resources.Requirement.parse(__name__), '.')) \
        if 'PROJECT_ROOT' not in os.environ else os.environ['PROJECT_ROOT']
except pkg_resources.DistributionNotFound:
    print('Running without installation. Likely on Spark Cluster.')
    PROJECT_ROOT = os.path.dirname(os.path.abspath(__file__))

os.environ['PROJECT_ROOT'] = PROJECT_ROOT

# define TRACKER_PATH for use with datatracker
os.environ['TRACKER_PATH'] = os.path.join(
    PROJECT_ROOT, os.path.basename(PROJECT_ROOT), 'db.json') \
    if 'TRACKER_PATH' not in os.environ else os.environ['TRACKER_PATH']

# modify if CLOUD_ROOT is not directly inferred from PROJECT_ROOT
os.environ['CLOUD_ROOT'] = f"gs://{__name__}" \
    if 'CLOUD_ROOT' not in os.environ else os.environ['CLOUD_ROOT']

from . import _version
__version__ = _version.get_versions()['version']



#!/usr/bin/env python3
"""
connector-cli (10 October 2023)
The Team Connector provides a short command-line interface (CLI) to connect
to the team's data and compute resources. Simple commands will sync and connect
files and results from your local computer to the team's cloud storage and 
the NYGC's compute cluster. 

For connector to work, the following environment variables must be set in your bash profile:
    HOME=/Users/[Your_Username]
    REMOTE_USER=[Your_Remote_Username]
    REMOTE_HOST=[Your_Remote_Host]
    REMOTE_DIR=/gpfs/commons/groups/[Your_Group_Name]
    GOOGLE_ROOT="/Users/[Your_Username]/Library/CloudStorage/[Your_GoogleDrive_Account]"
    MY_DRIVE="/Users/[Your_Username]/Library/CloudStorage/[Your_GoogleDrive_Account]/My Drive"
    SHARED_DRIVE="/Users/[Your_Username]/Library/CloudStorage/[Your_GoogleDrive_Account]/Shared Drives"
    ONE_DRIVE="/Users/[Your_Username]/Library/CloudStorage/[Your_OneDrive_Account]"
    SLACK_USER_ID=[Your_Slack_User_ID]
    SLACK_BOT_TOKEN=[Your_Slack_Bot_Token]

example:
    $ tc config
    $ tc drive -ls
    $ tc drive -o -p aouexplore -s sample_qc
    $ tc -d gcp --dir down --subdir phenotypes

(C) 2023, TJ Singh lab (singhlab@nygenome.org)
Source: www.github.com/tjsinghlab/connector
License: GNU General Public License v3
"""

__author__ = "Tarjinder Singh"
__version__ = "0.1.7"
__license__ = "MIT"

import os
import argparse
from loguru import logger

from . import googledrive as gd
from . import googlecloud as gc
from . import remote as sl

def describe_env_variables(args):
    if 'REMOTE_USER' in os.environ:
        print(f"REMOTE_USER:   {os.environ['REMOTE_USER']}")
    if 'REMOTE_HOST' in os.environ:
        print(f"REMOTE_HOST:   {os.environ['REMOTE_HOST']}")
    if 'MY_DRIVE' in os.environ:
        print(f"MY_DRIVE:   {os.environ['MY_DRIVE']}")
    if 'SHARED_DRIVE' in os.environ:
        print(f"SHARED_DRIVE:    {os.environ['SHARED_DRIVE']}")
    if 'ONE_DRIVE' in os.environ:
        print(f"ONE_DRIVE:      {os.environ['ONE_DRIVE']}")
    if 'GOOGLE_ROOT' in os.environ:
        print(f"GOOGLE_ROOT:    {os.environ['GOOGLE_ROOT']}")
    if 'CLOUD_ROOT' in os.environ:
        print(f"CLOUD_ROOT:   {os.environ['CLOUD_ROOT']}")
    if 'PROJECT_ROOT' in os.environ:
        print(f"PROJECT_ROOT:   {os.environ['PROJECT_ROOT']}")

def main():
    """ This is executed when run from the command line """
    parser = argparse.ArgumentParser(
        description=__doc__, formatter_class=argparse.RawDescriptionHelpFormatter)
    parser.add_argument('-d', '--debug', action='store_true', help='Enable debug mode')
    subparsers = parser.add_subparsers(title='Commands', dest='command')
    parser.add_argument("--version", action="version",
                        version="%(prog)s (version {version})".format(version=__version__))

    #----
    sync_drive_parser = subparsers.add_parser(
        'config', help='Show relevant environment variables.')

    #----
    # Subparser for the sync_drive command to connect to Google Drive
    sync_drive_parser = subparsers.add_parser(
        'drive', help='Connect local directory to a Google Drive directory.')
    sync_drive_parser.add_argument(
        '-d', '--dir', choices=['up', 'down'], help='Choose direction to sync files, with up being local to remote (default: up)', default='up')
    sync_drive_parser.add_argument(
        '-p', '--project-name', type=str, help='The basename of the Google Drive project directory to sync to. Defaults to CLOUD_ROOT, then to the name of the current working directory.')
    sync_drive_parser.add_argument(
        '-f', '--folder', choices=['src', 'data'], help='Choose folder to sync (default: data)', default='data')
    sync_drive_parser.add_argument(
        '-s', '--subdir', type=str, help='The subdirectory within the local src/ or data/ directory to sync.', default='')
    sync_drive_parser.add_argument(
        '-t', '--target', choices=['personal', 'shared'], help='Choose which folder to share (default: shared)', default='shared')
    sync_drive_parser.add_argument('--max-size-mb', type=int, default=10,
                                   help='The maximum size of files to sync, in megabytes. Defaults to 10.')
    sync_drive_parser.add_argument('-o', '--open', action='store_true', help='Open remote drive.')
    sync_drive_parser.add_argument('-ls', '--list', action='store_true', help='List  drive files.')

    #----
    # Subparser for the sync_bucket command to connect to Google Cloud Storage
    sync_drive_parser = subparsers.add_parser(
        'gcp', help='Connect local directory to a Google Cloud Storage bucket.')
    sync_drive_parser.add_argument(
        '-d', '--dir', choices=['up', 'down'], help='Choose direction to sync files, with up being local to remote (default: down)', default='down')
    sync_drive_parser.add_argument(
        '-f', '--folder', choices=['src', 'data'], help='Choose folder to sync (default: data)', default='data')
    sync_drive_parser.add_argument(
        '-s', '--subdir', type=str, help='The subdirectory within the local src/ or data/ directory to sync.', default='')
    sync_drive_parser.add_argument('--max-size-mb', type=int, default=10,
                                help='The maximum size of files to sync, in megabytes. Defaults to 10.')
    sync_drive_parser.add_argument('-o', '--open', action='store_true', help='Open remote bucket.')
    sync_drive_parser.add_argument('-ls', '--list', action='store_true', help='List bucket files.')

    #----
    # Subparser for the sync_remote command to connect to a remote filesystem
    sync_remote_parser = subparsers.add_parser(
        'remote', help='Connect local directory to a remote cluster filesystem.')
    sync_remote_parser.add_argument(
        '-u', '--user', type=str, help='The username for the remote cluster.')
    sync_remote_parser.add_argument(
        '-H', '--host', type=str, help='The hostname for the remote cluster.')
    sync_remote_parser.add_argument(
        '-r', '--remote-dir', type=str, help='The remote directory to sync to.')
    sync_remote_parser.add_argument(
        '-d', '--dir', choices=['up', 'down'], help='Choose direction to sync files, with up being local to remote (default: up)', default='up')
    sync_remote_parser.add_argument(
        '-s', '--subdir', type=str, help='The subdirectory within the local src/ or data/ directory to sync.', default='')
    sync_remote_parser.add_argument(
        '-f', '--folder', choices=['src', 'data'], help='Choose folder to sync (default: data)', default='data')
    sync_remote_parser.add_argument('--max-size-mb', type=int, default=10,
                                help='The maximum size of files to sync, in megabytes. Defaults to 10.')
    sync_remote_parser.add_argument('-ls', '--list', action='store_true', help='List remote cluster files.')

    args = parser.parse_args()
    
    if args.command == 'config':
        describe_env_variables(args)
    elif args.command == 'drive':
        gd.sync_drive(args)
    elif args.command == 'gcp':
        gc.sync_bucket(args)
    elif args.command == 'remote':
        sl.sync_remote(args)
    else:
        parser.print_help()

    return(0)




#!/usr/bin/env python3

import re
import os
import subprocess

def sync_drive(args):
    """Sync a local directory to a Google Drive directory using rsync."""
    try:
        drive_dir = f"{os.environ['MY_DRIVE']}"
        drive_dir = f"{os.environ['SHARED_DRIVE']}"
    except KeyError:
        print('MY_DRIVE environment variable is not defined. Error...')
        exit()
    if args.project_name is not None:
        project_name = args.project_name
    elif 'CLOUD_ROOT' in os.environ:
        project_name = os.environ['CLOUD_ROOT']
        project_name = re.sub('^gs://', '', project_name)
    else:
        project_name = os.path.basename(os.getcwd())
    local_dir = f"{args.folder}/{args.subdir}/"
    drive_dir = f"{project_name}/{args.folder}/{args.subdir}/"
    if args.target == 'personal':
        drive_dir = f"{os.environ['MY_DRIVE']}/{drive_dir}"
    else:
        drive_dir = f"{os.environ['SHARED_DRIVE']}/{drive_dir}"
    if args.open:
        cmd = ["open", f"{drive_dir}"]
        subprocess.run(cmd, check=True)
        return
    if args.list:
        cmd = ["ls", f"{os.environ['MY_DRIVE']}"] if args.target == 'personal' else ["ls", f"{os.environ['SHARED_DRIVE']}"]
        subprocess.run(cmd, check=True)
        return
    includes = ["--include=*.tsv", "--include=*.csv",
                "--include=*.txt", "--include=*.xlsx", "--include=*/"]
    excludes = ["--exclude=*"]
    max_size = f"--max-size={args.max_size_mb}mb"
    cmd = ["rsync", "-avhW"]
    if args.debug:
        cmd.append("--dry-run")
    cmd = cmd + includes + excludes + [max_size]
    if args.dir == 'up':
        cmd.extend([local_dir, drive_dir])
    else:
        cmd.extend([drive_dir, local_dir])
    subprocess.run(cmd, check=True)



"""
A module for setting environment variables for the active conda environment.

This module provides a `set_conda_env_vars` function that reads a `.env` file
located at a specified path and sets each non-commented line as an environment
variable for the active conda environment. Commented lines and empty lines are
skipped. If an error occurs while setting a variable, the function continues to
the next line and prints an error message.

The module also provides a `main` function that allows the `set_conda_env_vars`
function to be used as a command-line tool. The `main` function uses the
`argparse` module to parse command-line arguments and call the `set_conda_env_vars`
function with the specified file path.

Example usage
-------------
To set environment variables for the active conda environment based on a `.env`
file located at `/path/to/directory`, run the following command:

    python init_conda_env.py /path/to/directory
    python init_conda_env.py ~

Remember to deactivate and reactivate your conda environment to apply changes.
"""

import argparse
import subprocess
import os


def set_conda_env_vars(env_file_path='.'):
    """
    Set environment variables for the active conda environment based on a file.

    Parameters
    ----------
    env_file_path : str, optional
        The path to the directory containing the `.env` file. Defaults to the current directory.

    Raises
    ------
    FileNotFoundError
        If the `.env` file is not found at the specified path.

    Notes
    -----
    This function reads the `.env` file located at `env_file_path` 
    and sets each non-commented line as an environment variable 
    for the active conda environment. Commented lines and empty lines are skipped. 
    If an error occurs while setting a variable,
    the function continues to the next line and prints an error message.

    Example usage
    -------------
    >>> set_conda_env_vars('/path/to/directory')
    
    Remember to deactivate and reactivate your conda environment to apply changes.
    """
    env_file = os.path.join(env_file_path, '.env')

    if not os.path.exists(env_file):
        print(f"Error: .env file not found at {env_file_path}")
        return

    with open(env_file, 'r') as f:
        lines = f.readlines()

    for line in lines:
        line = line.strip()

        # Skip comments and empty lines
        if line.startswith('#') or not line:
            continue

        try:
            # Set environment variable for the active conda environment
            subprocess.run(['conda', 'env', 'config',
                            'vars', 'set', line], check=True)
        except subprocess.CalledProcessError as e:
            print(f"Error setting variable: {line}")
            print(f"Error message: {e}")
            continue

    print("Remember to deactivate and reactivate your conda environment to apply changes.")


def main():
    parser = argparse.ArgumentParser(
        description='Set environment variables for the active conda environment based on a file.')
    parser.add_argument('env_file_path', metavar='env_file_path', type=str, nargs='?', default='.',
                        help='the path to the directory containing the `.env` file (default: current directory)')

    args = parser.parse_args()

    set_conda_env_vars(args.env_file_path)


if __name__ == '__main__':
    main()




import os
import subprocess

def sync_remote(args):
    """Sync a local directory to a remote cluster filesystem using rsync."""
    try:
        remote_dir = f"{os.environ['REMOTE_DIR']}" if args.remote_dir is None else args.remote_dir
    except KeyError:
        print('REMOTE_DIR environment variable is not defined. Error...')
        exit()
        
    try:
        user = f"{os.environ['REMOTE_USER']}" if args.user is None else args.user
        host = f"{os.environ['REMOTE_HOST']}" if args.host is None else args.host
    except:
        print('REMOTE_USER or REMOTE_HOST environment variable is not defined. Error...')
        exit()
        
    if args.list:
        ssh_cmd = ["ssh", f"{user}@{host}", f"ls -l {remote_dir}"]
        subprocess.run(ssh_cmd, check=True)
        return
    
    local_dir = f"{args.folder}/{args.subdir}/"
    remote_dir = f"{user}@{host}:{remote_dir}/{args.folder}/{args.subdir}/"
    
    cmd = ["rsync", "-avhW"]
    includes = ["--include=*.tsv", "--include=*.csv",
                "--include=*.txt", "--include=*.xlsx", "--include=*/"]
    excludes = ["--exclude=*"]
    
    max_size = f"--max-size={args.max_size_mb}mb"
    if args.debug:
        cmd.append("--dry-run")
    cmd = cmd + includes + excludes + [max_size]
    if args.dir == 'up':
        cmd.extend([local_dir, remote_dir])
    else:
        cmd.extend([remote_dir, local_dir])
    print(" ".join(cmd))
    subprocess.run(cmd, check=True)



#!/usr/bin/env python3

from setuptools import setup, find_packages
import versioneer

with open('README.md', encoding='utf-8') as f:
    readme = f.read()

dependencies = []
with open('requirements.txt', 'r', encoding='utf-8') as f:
    for line in f:
        dependencies.append(line.strip())

setup(
    name='teamconnector',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description='Provides the default template for creating Python Package.',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='Singh Lab',
    author_email='singhlab@nygenome.org',
    url='https://github.com/tjsinghlab/connector',
    license='MIT license',
    python_requires='>=3.7',
    packages=find_packages(exclude=('tests', 'docs')),
    install_requires=dependencies,
    entry_points={
        'console_scripts': [
            'tc = connector.cli:main',
            'tcinit = connector.init_conda_env:main'
        ],
    }
)
